@@ -1,4 +1,5 @@
 from ..ui_tools.UI_tools import Ui_tools
+from time import sleep
 
 
 class OpenProject:
@@ -11,6 +12,7 @@ class OpenProject:
         OpenProject.input_file()
         OpenProject.confirm()
         OpenProject.close_dialog()
+        sleep(2)
 
     # 2a
     @staticmethod
